@@ -3,16 +3,7 @@ package DhMakeELPA::Command::Packaging;
 use strict;
 use warnings;
 
-use Cwd;
-use File::Basename qw{basename};
-use File::Grep qw{fgrep};
-use Array::Utils qw{array_minus};
-use DhMakeELPA::MELPA;
-use File::Copy;
-use File::Find::Rule;
-use File::Spec::Functions qw(catfile);
-use Git::Repository;
-use TryCatch;
+our $VERSION = '0.19';
 
 =head1 NAME
 
@@ -20,13 +11,164 @@ DhMakeELPA::Command::Packaging - routines for 'make' dh-make-elpa command
 
 =cut
 
-use base 'DhMakePerl::Command::Packaging';
+use base 'DhMakeELPA';
 
 __PACKAGE__->mk_accessors(
-                          qw( main_dir debian_dir bins control pkgname homepage elpa_version copyright gpl_version )
-                         );
+    qw( main_dir debian_dir
+        bins control pkgname
+        homepage elpa_version
+        copyright gpl_version
+        rules
+      )
+);
 
-use constant debstdversion => '4.4.0';
+use Array::Unique;
+use Array::Utils qw{array_minus};
+use Cwd;
+use Debian::Control;
+use Debian::Rules;
+use DhMakeELPA::MELPA;
+use File::Basename qw{basename};
+use File::Copy;
+use File::Find::Rule;
+use File::Grep qw{fgrep};
+use File::Path ();
+use File::Spec::Functions qw(catfile catpath splitpath);
+use Git::Repository;
+use TryCatch;
+
+use constant debstdversion => '4.5.0';
+
+our %DEFAULTS = (
+);
+
+sub new {
+    my $class = shift;
+    $class = ref($class) if ref($class);
+
+    my $self = $class->SUPER::new(@_);
+
+    while( my( $k, $v ) = each %DEFAULTS ) {
+        $self->$k($v) unless defined $self->$k;
+    }
+
+    $self->cfg or die "cfg is mandatory";
+
+    my @docs;
+    tie @docs, 'Array::Unique';
+
+    $self->docs( \@docs );
+
+    $self->control( Debian::Control->new )
+        unless $self->control;
+
+    return $self;
+}
+
+=head1 METHODS
+
+=over
+
+=item main_file(file_name)
+
+Constructs a file name relative to the main source directory, L</main_dir>
+
+=cut
+
+sub main_file {
+    my( $self, $file ) = @_;
+
+    catfile( $self->main_dir, $file );
+}
+
+=item debian_file(file_name)
+
+Constructs a file name relative to the debian/ sub-directory of the main source
+directory.
+
+=cut
+
+sub debian_file {
+    my( $self, $file ) = @_;
+
+    catfile( $self->main_file('debian'), $file );
+}
+
+sub get_user {
+    return $ENV{LOGNAME} || $ENV{USER};
+}
+
+sub get_email {
+    my $self = shift;
+    my $email = $self->cfg->{email};
+
+    $email ||= ( $ENV{DEBEMAIL} || $ENV{EMAIL} );
+    unless ($email) {
+	my $mailh;
+        chomp( $mailh = `cat /etc/mailname` );
+        $email = $self->get_user . '@' . $mailh;
+    }
+
+    $email =~ s/^(.*)\s+<(.*)>$/$2/;
+    return $email;
+}
+
+sub get_name {
+    my $self = shift;
+
+    my $name;
+    my $user = $self->get_user;
+    my $pwnam = getpwuid($<);
+    die "Cannot determine current user\n" unless $pwnam;
+    if ( defined $ENV{DEBFULLNAME} ) {
+        $name = $ENV{DEBFULLNAME};
+    }
+    else {
+        $name = $pwnam->gecos;
+        $name =~ s/,.*//;
+    }
+    $user ||= $pwnam->name;
+    $name ||= $user;
+    return $name;
+}
+
+sub get_developer {
+    my $self = shift;
+    return $self->get_name . " <" . $self->get_email . ">";
+}
+
+sub fill_maintainer {
+    my $self = shift;
+
+    my $src = $self->control->source;
+    my $maint = $self->get_developer;
+
+    if ( $self->cfg->pkg_emacsen ) {
+        my $pkg_emacsen_maint
+            = "Debian Emacsen team <debian-emacsen\@lists.debian.org>";
+        unless ( ( $src->Maintainer // '' ) eq $pkg_emacsen_maint ) {
+            my $old_maint = $src->Maintainer;
+            $src->Maintainer($pkg_emacsen_maint);
+            $src->Uploaders->add($old_maint) if $old_maint;
+        }
+
+        $src->Uploaders->add($maint);
+    }
+    else {
+        $src->Maintainer($maint);
+    }
+}
+
+sub get_wnpp {
+    my ( $self, $package ) = @_;
+
+    return undef unless $self->cfg->network;
+
+    my $wnpp = Debian::WNPP::Query->new(
+        { cache_file => catfile( $self->cfg->home_dir, 'wnpp.cache' ) } );
+    my @bugs = $wnpp->bugs_for_package($package);
+    return $bugs[0];
+}
 
 sub extract_basic {
     my $self = shift;
@@ -142,29 +284,6 @@ sub create_elpa {
     }
 }
 
-# from dh-make-perl
-sub fill_maintainer {
-    my $self = shift;
-
-    my $src = $self->control->source;
-    my $maint = $self->get_developer;
-
-    if ( $self->cfg->pkg_emacsen ) {
-        my $pkg_emacsen_maint
-            = "Debian Emacsen team <debian-emacsen\@lists.debian.org>";
-        unless ( ( $src->Maintainer // '' ) eq $pkg_emacsen_maint ) {
-            my $old_maint = $src->Maintainer;
-            $src->Maintainer($pkg_emacsen_maint);
-            $src->Uploaders->add($old_maint) if $old_maint;
-        }
-
-        $src->Uploaders->add($maint);
-    }
-    else {
-        $src->Maintainer($maint);
-    }
-}
-
 sub fill_vcs {
     my $self = shift;
     my $src = $self->control->source;
@@ -224,7 +343,7 @@ sub extract_description {
     return ($short_desc, $long_desc);
 }
 
-# TODO we might fall back to lookingg at the git tags
+# TODO we might fall back to looking at the git tags
 sub extract_version {
     my $self = shift;
     my $version;
@@ -349,6 +468,37 @@ EOT
     $fh->close;
 }
 
+sub create_rules {
+    my ( $self ) = @_;
+
+    my $file = $self->debian_file('rules');
+
+    $self->rules( Debian::Rules->new($file) );
+
+    if ( $self->rules->is_dhtiny ) {
+        print "$file already uses dh tiny rules\n"
+            if $self->cfg->verbose;
+        return;
+    }
+
+    $self->backup_file($file);
+
+    my $rulesname = 'rules.dh.tiny';
+
+    for my $source (
+        catfile( $self->cfg->{home_dir}, $rulesname ),
+        catfile( $self->cfg->{data_dir}, $rulesname )
+    ) {
+        if ( -e $source ) {
+            print "Using rules: $source\n" if $self->cfg->{verbose};
+            $self->rules->read($source);
+            last;
+        };
+    }
+    $self->rules->write;
+    chmod( 0755, $file ) or die "chmod($file): $!";
+}
+
 sub detect_buttercup_tests {
     my $self = shift;
 
@@ -364,12 +514,69 @@ sub detect_buttercup_tests {
     }
 }
 
+sub write_source_format {
+    my ( $self, $path ) = @_;
+
+    my ( $vol, $dir, $file ) = splitpath($path);
+    $dir = catpath( $vol, $dir );
+
+    if ( $self->cfg->{source_format} eq '1.0' ) {
+        # this is the default, remove debian/source
+        File::Path::rmtree($dir);
+    }
+    else {
+        # make sure the directory exists
+        File::Path::mkpath($dir) unless -d $dir;
+
+        my $fh = $self->_file_w($path);
+        $fh->print( $self->cfg->{source_format}, "\n" );
+        $fh->close;
+    }
+}
+
+=item backup_file(file_name)
+
+Creates a backup copy of the specified file by adding C<.bak> to its name. If
+the backup already exists, it is overwritten.
+
+Does nothing unless the C<backups> option is set.
+
+=cut
+
+sub backup_file {
+    my( $self, $file ) = @_;
+
+    if ( $self->cfg->backups ) {
+        warn "W: overwriting $file.bak\n"
+            if -e "$file.bak" and $self->cfg->verbose;
+        rename( $file, "$file.bak" );
+    }
+}
+
+sub _file_r {
+    my ( $self, $filename ) = @_;
+
+    my $fh = IO::File->new( $filename, 'r' )
+        or die "Cannot open $filename: $!\n";
+    return $fh;
+}
+
+sub _file_w {
+    my ( $self, $filename ) = @_;
+
+    my $fh = IO::File->new( $filename, 'w' )
+        or die "Cannot open $filename: $!\n";
+    return $fh;
+}
+
 =head1 COPYRIGHT & LICENSE
 
 =over
 
 =item Copyright (C) 2016-2018 Sean Whitton <spwhitton@spwhitton.name>
 
+=item Copyright (C) 2020 Lev Lamberov <dogsleg@debian.org>
+
 =back
 
 It is slightly based on the corresponding part of dh-make-perl, which
