@@ -10,7 +10,10 @@ This module implements the I<help> command of L<dh-make-elpa(1)>.
 
 =cut
 
-use strict; use warnings;
+use strict;
+use warnings;
+
+our $VERSION = '0.19';
 
 use base 'DhMakeELPA';
 use Pod::Usage;
@@ -36,13 +39,11 @@ sub execute {
 
 =cut
 
-1;
-
 =head1 COPYRIGHT & LICENSE
 
 =over
 
-=item Copyright (C) 2018 Lev Lamberov <dogsleg@debian.org>
+=item Copyright (C) 2018-2020 Lev Lamberov <dogsleg@debian.org>
 
 =back
 
@@ -68,3 +69,5 @@ this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
 Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 =cut
+
+1;
