@@ -4,21 +4,32 @@ use strict;
 use warnings;
 no warnings "experimental::smartmatch";
 
-use Debian::Control;
-use File::Spec::Functions qw(catfile);
-use Email::Date::Format qw(email_date);
-use File::Grep qw(fgrep);
-use File::Find::Rule;
-use Cwd;
+our $VERSION = '0.19';
 
 use base 'DhMakeELPA::Command::Packaging';
 
+__PACKAGE__->mk_accessors(
+    qw(
+        cfg apt_contents main_dir debian_dir meta
+        perlname version pkgversion
+        copyright author
+        extrasfields  extrapfields
+        docs examples
+        )
+);
+
 =head1 NAME
 
 DhMakeELPA::Command::make - implementation of 'dh-make-elpa make'
 
 =cut
 
+use Cwd;
+use Email::Date::Format qw(email_date);
+use File::Find::Rule;
+use File::Grep qw(fgrep);
+use File::Spec::Functions qw(catfile);
+
 sub execute {
     my $self = shift;
 
@@ -28,16 +39,16 @@ sub execute {
 
     # initial sanity check
     die "debian/ subdir already exists!  Won't clobber it.\n"
-      if ( -d $self->debian_dir );
+        if ( -d $self->debian_dir );
 
     # now start writing out package data
     mkdir( $self->debian_dir, 0755 )
-      or die "Cannot create " . $self->debian_dir . " dir: $!\n";
+        or die "Cannot create " . $self->debian_dir . " dir: $!\n";
     $self->create_elpa();
     $self->write_source_format(
         catfile( $self->debian_dir, 'source', 'format' ) );
     $self->create_changelog( $self->debian_file('changelog'),
-        $self->cfg->closes // $self->get_wnpp( $self->pkgname ) );
+        $self->cfg->{closes} // $self->get_wnpp( $self->pkgname ) );
     $self->create_rules();
     $self->create_control();
     $self->create_copyright();
@@ -50,12 +61,14 @@ sub execute {
 
 sub create_control {
     my $self = shift;
+
     my $src = $self->control->source;
 
     $src->Source( $self->pkgname );
     $src->Section("editors");
     $src->Priority("optional");
     $src->Standards_Version( $self->debstdversion );
+    $src->Rules_Requires_Root( "no" );
     $src->Build_Depends->add( sprintf "debhelper-compat (= %s)", $self->cfg->dh );
     $src->Build_Depends->add( "dh-elpa" );
     $src->Build_Depends->add( "elpa-buttercup" )
@@ -141,7 +154,13 @@ sub create_copyright {
     push @res, 'Source: ' . $self->homepage if ( defined $self->homepage );
     push @res, "";
     push @res, 'Files: *';
-    push @res, 'Copyright: ' . $self->copyright;
+    if ( defined $self->copyright ) {
+        push @res, 'Copyright: ' . $self->copyright;
+    } else {
+        push @res, 'Copyright: FIXME';
+        print("I: couldn't determine copyright holder -- added FIXME to debian/copyright.\n")
+    }
+
     push @res, 'License: GPL-' . $gpl_version . '+';
     push @res, "";
     push @res, 'Files: debian/*';
@@ -161,7 +180,7 @@ sub create_copyright {
           " GNU General Public License for more details.",
           " .",
           " You should have received a copy of the GNU General Public License",
-          " along with this program.  If not, see <http://www.gnu.org/licenses/>.",
+          " along with this program.  If not, see <https://www.gnu.org/licenses/>.",
           " .",
           " On Debian systems, the complete text of the GNU General",
           " Public License version $gpl_version can be found in `/usr/share/common-licenses/GPL-$gpl_version'",
@@ -170,9 +189,10 @@ sub create_copyright {
     push( @res,
           "",
           "DISCLAIMER: This copyright info was automatically extracted",
-          " from the ELPA package.  It might not be accurate.  You need",
+          " from the ELPA package. It might not be accurate. You need",
           " to throughly verify that the code passes the DFSG, and that",
-          " the info in this file is accurate.",
+          " the info in this file is accurate. In case there are any FIXME",
+          " in this file, these should be fixed.",
           "NOTE: Don't forget to remove this disclaimer when you've",
           " performed this verification."
           );
@@ -187,6 +207,8 @@ sub create_copyright {
 
 =item Copyright (C) 2016-2018 Sean Whitton <spwhitton@spwhitton.name>
 
+=item Copyright (C) 2020 Lev Lamberov <dogsleg@debian.org>
+
 =back
 
 It is slightly based on the corresponding part of dh-make-perl, which
