@@ -3,11 +3,7 @@ package DhMakeELPA::Config;
 use strict;
 use warnings;
 
-our $VERSION = '0.1.0';
-
-use base 'DhMakePerl::Config';
-
-use Getopt::Long;
+our $VERSION = '0.19';
 
 =head1 NAME
 
@@ -15,7 +11,16 @@ DhMakeELPA::Config - dh-make-elpa configuration class
 
 =cut
 
-my @OPTIONS = ( 'pkg-emacsen!', 'version=s' );
+use base 'Class::Accessor';
+use Dpkg::Source::Package;
+
+my @OPTIONS = (
+    'backups!',
+    'dh=i',
+    'network!',
+    'pkg-emacsen!',
+    'version=s'
+);
 
 my @COMMANDS = ( 'make', 'help' );
 
@@ -32,12 +37,29 @@ __PACKAGE__->mk_accessors(
     '_explicitly_set',
 );
 
+use Getopt::Long;
+
 use constant DEFAULTS => {
-                          dh            => 12,
-                          data_dir      => '/usr/share/dh-make-elpa',
-                          home_dir      => "$ENV{HOME}/.dh-make-elpa",
-                          source_format => '3.0 (quilt)',
-                         };
+    dh            => 13,
+    data_dir      => '/usr/share/dh-make-elpa',
+    home_dir      => "$ENV{HOME}/.dh-make-elpa",
+    source_format => '3.0 (quilt)',
+};
+
+sub new {
+    my $class = shift;
+    my $values = shift || {};
+
+    my $self = $class->SUPER::new(
+        {   %{ $class->DEFAULTS },
+            %$values,
+        },
+    );
+
+    $self->_explicitly_set( {} ) unless $self->_explicitly_set;
+
+    return $self;
+}
 
 =head1 METHODS
 
@@ -108,7 +130,7 @@ sub parse_command_line_options {
 
 =item Copyright (C) 2016-2018 Sean Whitton <spwhitton@spwhitton.name>
 
-=item Copyright (C) 2018 Lev Lamberov <dogsleg@debian.org>
+=item Copyright (C) 2018-2020 Lev Lamberov <dogsleg@debian.org>
 
 =back
 
